
# Slot: subject


parent genotype

URI: [biolink:genotype_to_variant_association_subject](https://w3id.org/biolink/vocab/genotype_to_variant_association_subject)


## Domain and Range

[GenotypeToVariantAssociation](GenotypeToVariantAssociation.md) &#8594;  <sub>1..1</sub> [Genotype](Genotype.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [GenotypeToVariantAssociation](GenotypeToVariantAssociation.md)
